@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use 5.008003;
 
-our $VERSION = '1.638';
+our $VERSION = '1.639';
 
 use Exporter qw( import );
 
@@ -63,7 +63,9 @@ sub table_char_width { [
 [   0x7a6,    0x7b0, 0],
 [   0x7b1,    0x7ea, 1],
 [   0x7eb,    0x7f3, 0],
-[   0x7f4,    0x815, 1],
+[   0x7f4,    0x7fc, 1],
+[   0x7fd,    0x7fd, 0],
+[   0x7fe,    0x815, 1],
 [   0x816,    0x819, 0],
 [   0x81a,    0x81a, 1],
 [   0x81b,    0x823, 0],
@@ -73,8 +75,8 @@ sub table_char_width { [
 [   0x829,    0x82d, 0],
 [   0x82e,    0x858, 1],
 [   0x859,    0x85b, 0],
-[   0x85c,    0x8d3, 1],
-[   0x8d4,    0x902, 0],
+[   0x85c,    0x8d2, 1],
+[   0x8d3,    0x902, 0],
 [   0x903,    0x939, 1],
 [   0x93a,    0x93a, 0],
 [   0x93b,    0x93b, 1],
@@ -97,7 +99,9 @@ sub table_char_width { [
 [   0x9cd,    0x9cd, 0],
 [   0x9ce,    0x9e1, 1],
 [   0x9e2,    0x9e3, 0],
-[   0x9e4,    0xa00, 1],
+[   0x9e4,    0x9fd, 1],
+[   0x9fe,    0x9fe, 0],
+[   0x9ff,    0xa00, 1],
 [   0xa01,    0xa02, 0],
 [   0xa03,    0xa3b, 1],
 [   0xa3c,    0xa3c, 0],
@@ -149,7 +153,9 @@ sub table_char_width { [
 [   0xbcd,    0xbcd, 0],
 [   0xbce,    0xbff, 1],
 [   0xc00,    0xc00, 0],
-[   0xc01,    0xc3d, 1],
+[   0xc01,    0xc03, 1],
+[   0xc04,    0xc04, 0],
+[   0xc05,    0xc3d, 1],
 [   0xc3e,    0xc40, 0],
 [   0xc41,    0xc45, 1],
 [   0xc46,    0xc48, 0],
@@ -489,7 +495,9 @@ sub table_char_width { [
 [  0xa8c4,   0xa8c5, 0],
 [  0xa8c6,   0xa8df, 1],
 [  0xa8e0,   0xa8f1, 0],
-[  0xa8f2,   0xa925, 1],
+[  0xa8f2,   0xa8fe, 1],
+[  0xa8ff,   0xa8ff, 0],
+[  0xa900,   0xa925, 1],
 [  0xa926,   0xa92d, 0],
 [  0xa92e,   0xa946, 1],
 [  0xa947,   0xa951, 0],
@@ -579,7 +587,11 @@ sub table_char_width { [
 [ 0x10a3f,  0x10a3f, 0],
 [ 0x10a40,  0x10ae4, 1],
 [ 0x10ae5,  0x10ae6, 0],
-[ 0x10ae7,  0x11000, 1],
+[ 0x10ae7,  0x10d23, 1],
+[ 0x10d24,  0x10d27, 0],
+[ 0x10d28,  0x10f45, 1],
+[ 0x10f46,  0x10f50, 0],
+[ 0x10f51,  0x11000, 1],
 [ 0x11001,  0x11001, 0],
 [ 0x11002,  0x11037, 1],
 [ 0x11038,  0x11046, 0],
@@ -591,7 +603,9 @@ sub table_char_width { [
 [ 0x110b9,  0x110ba, 0],
 [ 0x110bb,  0x110bc, 1],
 [ 0x110bd,  0x110bd, 0],
-[ 0x110be,  0x110ff, 1],
+[ 0x110be,  0x110cc, 1],
+[ 0x110cd,  0x110cd, 0],
+[ 0x110ce,  0x110ff, 1],
 [ 0x11100,  0x11102, 0],
 [ 0x11103,  0x11126, 1],
 [ 0x11127,  0x1112b, 0],
@@ -603,8 +617,8 @@ sub table_char_width { [
 [ 0x11180,  0x11181, 0],
 [ 0x11182,  0x111b5, 1],
 [ 0x111b6,  0x111be, 0],
-[ 0x111bf,  0x111c9, 1],
-[ 0x111ca,  0x111cc, 0],
+[ 0x111bf,  0x111c8, 1],
+[ 0x111c9,  0x111cc, 0],
 [ 0x111cd,  0x1122e, 1],
 [ 0x1122f,  0x11231, 0],
 [ 0x11232,  0x11233, 1],
@@ -619,8 +633,8 @@ sub table_char_width { [
 [ 0x112e3,  0x112ea, 0],
 [ 0x112eb,  0x112ff, 1],
 [ 0x11300,  0x11301, 0],
-[ 0x11302,  0x1133b, 1],
-[ 0x1133c,  0x1133c, 0],
+[ 0x11302,  0x1133a, 1],
+[ 0x1133b,  0x1133c, 0],
 [ 0x1133d,  0x1133f, 1],
 [ 0x11340,  0x11340, 0],
 [ 0x11341,  0x11365, 1],
@@ -633,7 +647,9 @@ sub table_char_width { [
 [ 0x11442,  0x11444, 0],
 [ 0x11445,  0x11445, 1],
 [ 0x11446,  0x11446, 0],
-[ 0x11447,  0x114b2, 1],
+[ 0x11447,  0x1145d, 1],
+[ 0x1145e,  0x1145e, 0],
+[ 0x1145f,  0x114b2, 1],
 [ 0x114b3,  0x114b8, 0],
 [ 0x114b9,  0x114b9, 1],
 [ 0x114ba,  0x114ba, 0],
@@ -669,10 +685,12 @@ sub table_char_width { [
 [ 0x11722,  0x11725, 0],
 [ 0x11726,  0x11726, 1],
 [ 0x11727,  0x1172b, 0],
-[ 0x1172c,  0x11a00, 1],
-[ 0x11a01,  0x11a06, 0],
-[ 0x11a07,  0x11a08, 1],
-[ 0x11a09,  0x11a0a, 0],
+[ 0x1172c,  0x1182e, 1],
+[ 0x1182f,  0x11837, 0],
+[ 0x11838,  0x11838, 1],
+[ 0x11839,  0x1183a, 0],
+[ 0x1183b,  0x11a00, 1],
+[ 0x11a01,  0x11a0a, 0],
 [ 0x11a0b,  0x11a32, 1],
 [ 0x11a33,  0x11a38, 0],
 [ 0x11a39,  0x11a3a, 1],
@@ -711,7 +729,15 @@ sub table_char_width { [
 [ 0x11d3f,  0x11d45, 0],
 [ 0x11d46,  0x11d46, 1],
 [ 0x11d47,  0x11d47, 0],
-[ 0x11d48,  0x16aef, 1],
+[ 0x11d48,  0x11d8f, 1],
+[ 0x11d90,  0x11d91, 0],
+[ 0x11d92,  0x11d94, 1],
+[ 0x11d95,  0x11d95, 0],
+[ 0x11d96,  0x11d96, 1],
+[ 0x11d97,  0x11d97, 0],
+[ 0x11d98,  0x11ef2, 1],
+[ 0x11ef3,  0x11ef4, 0],
+[ 0x11ef5,  0x16aef, 1],
 [ 0x16af0,  0x16af4, 0],
 [ 0x16af5,  0x16b2f, 1],
 [ 0x16b30,  0x16b36, 0],
